import 'package:flutter/material.dart';
import 'package:lists_and_grids/bob_data.dart';

void main() {
  WidgetsFlutterBinding.ensureInitialized();
  runApp(const MaterialApp(title: "BobRoss", home: HomeScreen()));
}

class HomeScreen extends StatelessWidget {
  const HomeScreen({super.key});

  @override
  Widget build(BuildContext context) {
    BobRossData data = BobRossData();
    return Scaffold(
      appBar: AppBar(title: Text("Home")),
      drawer: Drawer(
        child: ListView(
          children: [
            DrawerHeader(child: Text("Pick your destination")),
            ListTile(
              leading: Icon(Icons.home),
              title: Text("Home"),
              onTap: () {
                Navigator.of(context).pop();
                Navigator.of(context).push(
                    MaterialPageRoute(builder: (context) => HomeScreen()));
              },
            ),
            ListTile(
              leading: Icon(Icons.list),
              title: Text("List View"),
              onTap: () {
                Navigator.of(context).pop();
                Navigator.of(context).push(MaterialPageRoute(
                    builder: (context) => ListScreen(data.paintingNames)));
              },
            ),
            ListTile(
              leading: Icon(Icons.grid_3x3),
              title: Text("Grid View"),
              onTap: () {
                Navigator.of(context).pop();
                Navigator.of(context).push(MaterialPageRoute(
                    builder: (context) => GridScreen(data.paintings)));
              },
            ),
          ],
        ),
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            ElevatedButton(
              onPressed: () {
                Navigator.of(context).push(
                  MaterialPageRoute(
                      builder: (context) => ListScreen(data.paintingNames)),
                );
              },
              child: Text("Go to ListView Screen"),
            ),
            const SizedBox(height: 8),
            ElevatedButton(
              onPressed: () {
                // This is the recipe for forward navigation.
                // NAvigator widget to actually move.
                Navigator.of(context).push(
                  MaterialPageRoute(
                      // Whatever is on the right side of => is the widget to navigate to
                      builder: (context) => GridScreen(data.paintings)),
                );
              },
              child: Text("Go to GridView Screen"),
            ),
            const SizedBox(height: 8),
            ElevatedButton(
              onPressed: () {
                // This is the recipe for forward navigation.
                // NAvigator widget to actually move.
                Navigator.of(context).push(
                  MaterialPageRoute(
                      // Whatever is on the right side of => is the widget to navigate to
                      builder: (context) => DetailScreen()),
                );
              },
              child: Text("Go to Detail Screen"),
            )
          ],
        ),
      ),
    );
  }
}

class ListScreen extends StatelessWidget {
  const ListScreen(this.paintingNames, {super.key});

  final List<String> paintingNames;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: const Text("ListView")),
      backgroundColor: Colors.grey[800],
      body: ListView.builder(
        padding: const EdgeInsets.all(16),
        itemBuilder: (context, index) {
          return Card(
            child: ListTile(
              onTap: () => print("You clicked on ${paintingNames[index]}"),
              leading: const Icon(Icons.brush),
              title: Text(paintingNames[index]),
              subtitle: const Text("Bob Ross"),
              trailing: const Icon(Icons.more_vert),
            ),
          );
          // return Container(
          //   decoration: BoxDecoration(border: Border.all(width: 3)),
          //   child: Text(
          //     bobRossPaintings[index],
          //     style: const TextStyle(fontSize: 32, color: Colors.teal),
          //   ),
          // );
        },
      ),
    );
  }
}

class GridScreen extends StatelessWidget {
  const GridScreen(this.paintings, {super.key});

  final List<BobRossPainting> paintings;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(title: const Text("GridView")),
        backgroundColor: Colors.grey[800],
        body: GridView.builder(
          padding: const EdgeInsets.all(8),
          itemCount: paintings.length,
          gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(
            crossAxisCount: 2,
            mainAxisSpacing: 8,
            crossAxisSpacing: 16,
          ),
          itemBuilder: (context, index) => MyCard(painting: paintings[index]),
        ));
  }
}

class MyCard extends StatelessWidget {
  const MyCard({required this.painting, super.key});
  final BobRossPainting painting;

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () {
        Navigator.of(context).push(MaterialPageRoute(
            builder: (context) => DetailScreen(painting: painting)));
      },
      child: Card(
        child: Padding(
          padding: const EdgeInsets.all(4),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Image.asset("assets/images/painting${painting.paintingId}.png"),
              Text(
                painting.title,
                style: TextStyle(
                  color: Colors.grey[700],
                  fontSize: 14,
                  fontWeight: FontWeight.bold,
                ),
              ),
              Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Text("S.${painting.season} Ep.${painting.episode}"),
                  Text("Colors: ${painting.colorCount}")
                ],
              )
            ],
          ),
        ),
      ),
    );
  }
}

class DetailScreen extends StatelessWidget {
  const DetailScreen({this.painting, super.key});

  final BobRossPainting? painting;

  @override
  Widget build(BuildContext context) {
    Widget contentToShow;

    // If you have a Stateless widget, and you need to configure how it looks
    // Use the widget parameters and some if-statements to customize what you
    // return
    if (painting != null) {
      contentToShow =
          Image.asset("assets/images/painting${painting!.paintingId}.png");
    } else {
      contentToShow = Text("Nothing to see here!");
    }

    return Scaffold(
      appBar: AppBar(title: Text("DetailScreen")),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            // I want an Image if there is one to show.
            // OR, display some Text if I don't have an image.
            contentToShow,
            ElevatedButton(
              onPressed: () => Navigator.of(context).pop(),
              child: Text("Go back"),
            )
          ],
        ),
      ),
    );
  }
}
